==> alg-feature-1.37.18-20200729.024153-1-sources.jar: cn/com/duiba/nezha/alg/feature/vo/SkinFeature.java <==
package cn.com.duiba.nezha.alg.feature.vo;

public class SkinFeature {

    // 皮肤
    private String SkinId;
    private String componentSkinCategory; //f314001 皮肤类型
    private Double componentSkinHistClick;   //f314004 历史点击率
    private Double componentSkinWeekClick; //f314005 一周点击率
    private Double componentSkinDayClick;   //f314006 当日点击率
    private Double componentSkinHistOrder;   //f314007 历史转化率
    private Double componentSkinWeekOrder; //f314008 一周转化率
    private Double componentSkinDayOrder; //f314009 当日转化率

    public String getSkinId() {
        return SkinId;
    }

    public void setSkinId(String skinId) {
        SkinId = skinId;
    }

    public String getComponentSkinCategory() {
        return componentSkinCategory;
    }

    public void setComponentSkinCategory(String componentSkinCategory) {
        this.componentSkinCategory = componentSkinCategory;
    }

    public Double getComponentSkinHistClick() {
        return componentSkinHistClick;
    }

    public void setComponentSkinHistClick(Double componentSkinHistClick) {
        this.componentSkinHistClick = componentSkinHistClick;
    }

    public Double getComponentSkinWeekClick() {
        return componentSkinWeekClick;
    }

    public void setComponentSkinWeekClick(Double componentSkinWeekClick) {
        this.componentSkinWeekClick = componentSkinWeekClick;
    }

    public Double getComponentSkinDayClick() {
        return componentSkinDayClick;
    }

    public void setComponentSkinDayClick(Double componentSkinDayClick) {
        this.componentSkinDayClick = componentSkinDayClick;
    }

    public Double getComponentSkinHistOrder() {
        return componentSkinHistOrder;
    }

    public void setComponentSkinHistOrder(Double componentSkinHistOrder) {
        this.componentSkinHistOrder = componentSkinHistOrder;
    }

    public Double getComponentSkinWeekOrder() {
        return componentSkinWeekOrder;
    }

    public void setComponentSkinWeekOrder(Double componentSkinWeekOrder) {
        this.componentSkinWeekOrder = componentSkinWeekOrder;
    }

    public Double getComponentSkinDayOrder() {
        return componentSkinDayOrder;
    }

    public void setComponentSkinDayOrder(Double componentSkinDayOrder) {
        this.componentSkinDayOrder = componentSkinDayOrder;
    }



}

==> alg-feature-1.39.20-20201022.075856-1-sources.jar: cn/com/duiba/nezha/alg/feature/vo/SkinFeature.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;


public class SkinFeature implements Serializable {

    // 皮肤
    private String SkinId;
    private String componentSkinCategory; //f314001 皮肤类型
    private Double componentSkinHistClick;   //f314004 历史点击率
    private Double componentSkinWeekClick; //f314005 一周点击率
    private Double componentSkinDayClick;   //f314006 当日点击率
    private Double componentSkinHistOrder;   //f314007 历史转化率
    private Double componentSkinWeekOrder; //f314008 一周转化率
    private Double componentSkinDayOrder; //f314009 当日转化率

    public String getSkinId() {
        return SkinId;
    }

    public void setSkinId(String skinId) {
        SkinId = skinId;
    }

    public String getComponentSkinCategory() {
        return componentSkinCategory;
    }

    public void setComponentSkinCategory(String componentSkinCategory) {
        this.componentSkinCategory = componentSkinCategory;
    }

    public Double getComponentSkinHistClick() {
        return componentSkinHistClick;
    }

    public void setComponentSkinHistClick(Double componentSkinHistClick) {
        this.componentSkinHistClick = componentSkinHistClick;
    }

    public Double getComponentSkinWeekClick() {
        return componentSkinWeekClick;
    }

    public void setComponentSkinWeekClick(Double componentSkinWeekClick) {
        this.componentSkinWeekClick = componentSkinWeekClick;
    }

    public Double getComponentSkinDayClick() {
        return componentSkinDayClick;
    }

    public void setComponentSkinDayClick(Double componentSkinDayClick) {
        this.componentSkinDayClick = componentSkinDayClick;
    }

    public Double getComponentSkinHistOrder() {
        return componentSkinHistOrder;
    }

    public void setComponentSkinHistOrder(Double componentSkinHistOrder) {
        this.componentSkinHistOrder = componentSkinHistOrder;
    }

    public Double getComponentSkinWeekOrder() {
        return componentSkinWeekOrder;
    }

    public void setComponentSkinWeekOrder(Double componentSkinWeekOrder) {
        this.componentSkinWeekOrder = componentSkinWeekOrder;
    }

    public Double getComponentSkinDayOrder() {
        return componentSkinDayOrder;
    }

    public void setComponentSkinDayOrder(Double componentSkinDayOrder) {
        this.componentSkinDayOrder = componentSkinDayOrder;
    }



}
